SpaCo: SpaCo

View source: R/SpaCo.R

SpaCoR Documentation

SpaCo

Description

SpaCo

Usage

SpaCo(
  SpaCoObject,
  PC_criterion = "percent",
  PC_value = 0.95,
  set_nspacs = NULL,
  nSim = 1000,
  nSpacQuantile = 0.05,
  reducedSpots = FALSE,
  nReduce = 1000
)

Arguments

SpaCoObject

Object of class SpaCoObject as generated from [SpaCoObject] on which to perform SCA.

PC_criterion

criterion on which to select number of principal components for initial covariance matrix reconstruction; either "number" to select a number of PCs or "percent" to select number of PCs to explain specified amount of data variance

PC_value

Value to specify number of PCs or desired level of explained variance, see "PC_criterion"

set_nspacs

Boolean if number of relevant spacs is to be computed. Increases run time significantly

nSim

Number of simulations for computation of spac number

nSpacQuantile

Quantile to use as cutoff for spac number

reducedSpots

Should algorithm be run on a subset of spots? Default = FALSE

nReduce

Number of spots to sample to run algorithm on subset if reducedSpots==TRUE. Ignored if reducedSpots==FALSE

Value

Returns a SpaCoObject filled with the result of the spatial component analysis.


SPACO documentation built on March 31, 2026, 5:07 p.m.

Related to SpaCo in SPACO...