SpaCoObject: Create a constructor function that creates an object of class...

View source: R/SpacoObject_constructor.R

SpaCoObjectR Documentation

Create a constructor function that creates an object of class SpaCoObject

Description

Create a constructor function that creates an object of class SpaCoObject

Usage

SpaCoObject(neighbours, data, coordinates)

Arguments

neighbours

Binary matrix with weights describing if cells are to be considered neighbours or not depending on the defined distance.

data

Matrix with normalized and scaled gene counts. Rows as cells and genes as columns

coordinates

Matri with the cell coordinates on the slides. Rows and Columns in the 10x Visium case.

Value

Returns a SpaCoObject with the given slots filled


SPACO documentation built on March 31, 2026, 5:07 p.m.

Related to SpaCoObject in SPACO...