denoise_profiles: computes smoothed gene profiles of genes present in the data.

View source: R/AuxiliaryFunctions.R

denoise_profilesR Documentation

computes smoothed gene profiles of genes present in the data.

Description

computes smoothed gene profiles of genes present in the data.

Usage

denoise_profiles(SpaCoObject)

Arguments

SpaCoObject

Spaco object to compute profiles of.

Value

smoothed gene profiles in the SpaCoObject.


SPACO documentation built on March 31, 2026, 5:07 p.m.