read_10x_for_spaco: Read in 10x Visium spatial transcriptomics data

View source: R/read_10x_for_spaco.R

read_10x_for_spacoR Documentation

Read in 10x Visium spatial transcriptomics data

Description

Read in 10x Visium spatial transcriptomics data

Usage

read_10x_for_spaco(
  data_dir,
  slice,
  filename,
  variable_features_n = variable_features_n,
  spatial_file = spatial_file,
  vars_to_regress = NULL
)

Arguments

data_dir

Directory containing the H5 file specified by file name and the image data in a sub directory called spatial

slice

Name for the stored image of the tissue slice

filename

Filename of data to be read

variable_features_n

Number of most variable features to keep.

spatial_file

Name of csv file from which to read tissue positions.

vars_to_regress

Names of features to be regressed against using PercentageFeatureSet

Value

Retuns a ready to run SPaCoObject.


SPACO documentation built on March 31, 2026, 5:07 p.m.