set_projection: Set projections of Spaco Object

View source: R/set_projection.R

set_projectionR Documentation

Set projections of Spaco Object

Description

Set projections of Spaco Object

Usage

set_projection(SpaCoObject, data, neighborhood = SpaCoObject@neighbours)

Arguments

SpaCoObject

Fitted object of class SpaCoObject as returned from [SpaCo] on which to update the projection slot with new data.

data

gene expression data matrix; p genes as columns, n loci as rows

neighborhood

neighborhood matrix of the new data. Must be of dimension n times n, where n is the number of columns of data

Value

Returns the SpaCoObject with the updated data, neighborhood matrix, and projection matrix.


SPACO documentation built on March 31, 2026, 5:07 p.m.

Related to set_projection in SPACO...