seurat_to_spaco: Wrapper to transform existing Seurat object into an...

View source: R/Seuratwrappers.R

seurat_to_spacoR Documentation

Wrapper to transform existing Seurat object into an SpaCoObject.

Description

Wrapper to transform existing Seurat object into an SpaCoObject.

Usage

seurat_to_spaco(SeuratObject, assay = "SCT", n_image = 1, layer = "scale.data")

Arguments

SeuratObject

Seurat object to export

assay

Assay to export from the Seurat object. Default is SCT assay.

n_image

Number of the image to export from Seurat object. Only relevant if Seurat object contains multiple images. Default is 1.

layer

Which layer to export data from. Default is scale.data.

Value

Returns a SpaCoObject with all slots filled necessary to perform the spatial component analysis.


SPACO documentation built on March 31, 2026, 5:07 p.m.

Related to seurat_to_spaco in SPACO...