spacs_to_seurat: transfer computed spatial components to existing Seurat...

View source: R/Seuratwrappers.R

spacs_to_seuratR Documentation

transfer computed spatial components to existing Seurat object.

Description

transfer computed spatial components to existing Seurat object.

Usage

spacs_to_seurat(SpaCoObject, SeuratObject, nSpacs = SpaCoObject@nSpacs)

Arguments

SpaCoObject

SpaCoObject to export spatial components from.

SeuratObject

Seurat object to add spatial components to.

nSpacs

Number of Spacs which are to be projected on for dimension reduction

Value

Returns a Seurat Object with the spatial components projections in the dimensional reduction slot.


SPACO documentation built on March 31, 2026, 5:07 p.m.

Related to spacs_to_seurat in SPACO...