subset_non_neighbour_cells: Filtering function to remove cells without neighbours in...

View source: R/Seuratwrappers.R

subset_non_neighbour_cellsR Documentation

Filtering function to remove cells without neighbours in defined distance from existing Seurat object to be conformable with existing SpaCoObject.

Description

Filtering function to remove cells without neighbours in defined distance from existing Seurat object to be conformable with existing SpaCoObject.

Usage

subset_non_neighbour_cells(SpaCoObject, SeuratObject)

Arguments

SpaCoObject

SpaCoObject to integrate into Seurat object.

SeuratObject

Seurat object to be filtered.

Value

Returns a Seurat object with cells filtered to match SpaCoObject.


SPACO documentation built on March 31, 2026, 5:07 p.m.