View source: R/SpacoObject_constructor.R
| SpaCoObject | R Documentation |
Create a constructor function that creates an object of class SpaCoObject
SpaCoObject(neighbours, data, coordinates)
neighbours |
Binary matrix with weights describing if cells are to be considered neighbours or not depending on the defined distance. |
data |
Matrix with normalized and scaled gene counts. Rows as cells and genes as columns |
coordinates |
Matri with the cell coordinates on the slides. Rows and Columns in the 10x Visium case. |
Returns a SpaCoObject with the given slots filled
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.