View source: R/read_10x_for_spaco.R
| read_10x_for_spaco | R Documentation |
Read in 10x Visium spatial transcriptomics data
read_10x_for_spaco(
data_dir,
slice,
filename,
variable_features_n = variable_features_n,
spatial_file = spatial_file,
vars_to_regress = NULL
)
data_dir |
Directory containing the H5 file specified by file name and the image data in a sub directory called spatial |
slice |
Name for the stored image of the tissue slice |
filename |
Filename of data to be read |
variable_features_n |
Number of most variable features to keep. |
spatial_file |
Name of csv file from which to read tissue positions. |
vars_to_regress |
Names of features to be regressed against using PercentageFeatureSet |
Retuns a ready to run SPaCoObject.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.