View source: R/set_projection.R
| set_projection | R Documentation |
Set projections of Spaco Object
set_projection(SpaCoObject, data, neighborhood = SpaCoObject@neighbours)
SpaCoObject |
Fitted object of class |
data |
gene expression data matrix; p genes as columns, n loci as rows |
neighborhood |
neighborhood matrix of the new data. Must be of dimension n times n, where n is the number of columns of |
Returns the SpaCoObject with the updated data, neighborhood matrix, and projection matrix.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.