View source: R/Seuratwrappers.R
| seurat_to_spaco | R Documentation |
Wrapper to transform existing Seurat object into an SpaCoObject.
seurat_to_spaco(SeuratObject, assay = "SCT", n_image = 1, layer = "scale.data")
SeuratObject |
Seurat object to export |
assay |
Assay to export from the Seurat object. Default is SCT assay. |
n_image |
Number of the image to export from Seurat object. Only relevant if Seurat object contains multiple images. Default is 1. |
layer |
Which layer to export data from. Default is scale.data. |
Returns a SpaCoObject with all slots filled necessary to perform the spatial component analysis.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.