View source: R/Seuratwrappers.R
| spacs_to_seurat | R Documentation |
transfer computed spatial components to existing Seurat object.
spacs_to_seurat(SpaCoObject, SeuratObject, nSpacs = SpaCoObject@nSpacs)
SpaCoObject |
SpaCoObject to export spatial components from. |
SeuratObject |
Seurat object to add spatial components to. |
nSpacs |
Number of Spacs which are to be projected on for dimension reduction |
Returns a Seurat Object with the spatial components projections in the dimensional reduction slot.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.