View source: R/Seuratwrappers.R
| subset_non_neighbour_cells | R Documentation |
Filtering function to remove cells without neighbours in defined distance from existing Seurat object to be conformable with existing SpaCoObject.
subset_non_neighbour_cells(SpaCoObject, SeuratObject)
SpaCoObject |
SpaCoObject to integrate into Seurat object. |
SeuratObject |
Seurat object to be filtered. |
Returns a Seurat object with cells filtered to match SpaCoObject.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.